<?php

use Acms\Services\Update\System\CheckForUpdate;
use Acms\Services\Facades\Storage;

class ACMS_GET_Admin_Update extends ACMS_GET_Admin
{
    function get()
    {
        if ( 'update' <> ADMIN ) return false;
        // ToDo: Limited Administrator & root user

        $Tpl = new Template($this->tpl, new ACMS_Corrector());
        $updateService = App::make('update');
        $checkUpdateService = App::make('update.check');
        $logger = App::make('update.logger');

        $rootVars = array(
            'finalCheckTime' => date('Y/m/d H:i:s', $checkUpdateService->getFinalCheckTime()),
        );
        $dbVars = array(
            'databaseVersion' => $updateService->databaseVersion,
            'systemVersion' => $updateService->systemVersion,
        );

        try {
            /**
             * システムアップデート中チェック
             */
            if ( Storage::exists($logger->getDestinationPath()) ) {
                $rootVars['processing'] = 1;
            } else {
                $rootVars['processing'] = 0;
            }

            /**
             * データベースのバージョンチェック
             */
            $check = $updateService->checkUpdates();
            if ( $check ) {
                $Tpl->add('update', $dbVars);
            } else {
                $Tpl->add('match', $dbVars);
            }

            /**
             * システムのバージョンチェック
             */
            $range = CheckForUpdate::PATCH_VERSION;
            if ( config('system_update_range') === 'minor' ) {
                $range = CheckForUpdate::MINOR_VERSION;
            }
            if ( $checkUpdateService->checkUseCache(phpversion(), $range) ) {
                $Tpl->add('old_version', array(
                    'version' => $checkUpdateService->getUpdateVersion(),
                    'downloadUrl' => $checkUpdateService->getPackageUrl(),
                ));
            } else {
                if ( config('system_update_range') === 'minor' ) {
                    $Tpl->add('latest:minor', array());
                } else {
                    $Tpl->add('latest:patch', array());
                }
            }

        } catch ( \Exception $e ) {
            $Tpl->add('error', $dbVars);
        }

        $Tpl->add(null, $rootVars);

        return $Tpl->get();
    }
}
